# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2


class ModelPublicServiceStub(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Liveness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Readiness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
                )
        self.ListModelDefinitions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
                )
        self.GetModelDefinition = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
                )
        self.ListModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
                )
        self.LookUpModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/LookUpModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
                )
        self.ListUserModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListUserModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
                )
        self.CreateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
                )
        self.CreateUserModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/CreateUserModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadResponse.FromString,
                )
        self.GetUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
                )
        self.UpdateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
                )
        self.DeleteUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
                )
        self.RenameUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
                )
        self.PublishUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/PublishUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelResponse.FromString,
                )
        self.UnpublishUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UnpublishUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelResponse.FromString,
                )
        self.DeployUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeployUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelResponse.FromString,
                )
        self.UndeployUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UndeployUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelResponse.FromString,
                )
        self.GetUserModelCard = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserModelCard',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardResponse.FromString,
                )
        self.WatchUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
                )
        self.TriggerUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
                )
        self.TriggerUserModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
                )
        self.ListOrganizationModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
                )
        self.CreateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
                )
        self.CreateOrganizationModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/CreateOrganizationModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadResponse.FromString,
                )
        self.GetOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
                )
        self.UpdateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
                )
        self.DeleteOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
                )
        self.RenameOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
                )
        self.PublishOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/PublishOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelResponse.FromString,
                )
        self.UnpublishOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UnpublishOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelResponse.FromString,
                )
        self.DeployOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeployOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelResponse.FromString,
                )
        self.UndeployOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UndeployOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelResponse.FromString,
                )
        self.GetOrganizationModelCard = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationModelCard',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardResponse.FromString,
                )
        self.WatchOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
                )
        self.TriggerOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
                )
        self.TriggerOrganizationModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
                )
        self.GetModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
                )


class ModelPublicServiceServicer(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def Liveness(self, request, context):
        """Check if the model server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the model server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModelDefinitions(self, request, context):
        """List model definitions

        Returns a paginated list of model definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelDefinition(self, request, context):
        """Get a model definition

        Returns the details of a model definition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """List models

        Returns a paginated list of models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpModel(self, request, context):
        """Get a model by UID

        Returns the details of a model by a permalink defined by the resource UID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserModels(self, request, context):
        """List user models

        Returns a paginated list of models that belong to the specified user. The
        parent user may be different from the authenticated user, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of a user. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserModelBinaryFileUpload(self, request_iterator, context):
        """Upload model binary

        Creates a new model by upploading its binary content.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent user and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameUserModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishUserModel(self, request, context):
        """Publish a model

        Updates the visibility in a model to PUBLIC. The model is accessed by its
        resource name, defined by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnpublishUserModel(self, request, context):
        """Unpublish a model

        Updates the visibility in a model to PRIVATE. The model is accessed by its
        resource name, defined by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployUserModel(self, request, context):
        """Deploy a model

        Transitions the model into an ONLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent user.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the deployment might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployUserModel(self, request, context):
        """Undeploy a model

        Transitions the model into an OFFLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent user.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the teardown might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserModelCard(self, request, context):
        """Get a model card

        Returns the README file that accompanies a model, describing it and
        enhancing it with metadata. The model is accessed by its resource name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUserModel(self, request, context):
        """Watch the state of a model

        Returns the state of a model. The deploy / undeploy actions take some
        time, during which a model will be in an UNSPECIFIED state. This endpoint
        allows clients to track the state and progress of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationModels(self, request, context):
        """List organization models

        Returns a paginated list of models that belong to the specified organization. The
        parent organization may be different from the authenticated organization, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of an organization. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationModelBinaryFileUpload(self, request_iterator, context):
        """Upload model binary

        Creates a new model by upploading its binary content.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent organization and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameOrganizationModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishOrganizationModel(self, request, context):
        """Publish a model

        Updates the visibility in a model to PUBLIC. The model is accessed by its
        resource name, defined by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnpublishOrganizationModel(self, request, context):
        """Unpublish a model

        Updates the visibility in a model to PRIVATE. The model is accessed by its
        resource name, defined by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployOrganizationModel(self, request, context):
        """Deploy a model

        Transitions the model into an ONLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent organization.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the deployment might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployOrganizationModel(self, request, context):
        """Undeploy a model

        Transitions the model into an OFFLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent organization.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the teardown might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationModelCard(self, request, context):
        """Get a model card

        Returns the README file that accompanies a model, describing it and
        enhancing it with metadata. The model is accessed by its resource name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchOrganizationModel(self, request, context):
        """Watch the state of a model

        Returns the state of a model. The deploy / undeploy actions take some
        time, during which a model will be in an UNSPECIFIED state. This endpoint
        allows clients to track the state and progress of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOperation(self, request, context):
        """Get the details of a long-running operation

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.SerializeToString,
            ),
            'ListModelDefinitions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelDefinitions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.SerializeToString,
            ),
            'GetModelDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelDefinition,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.SerializeToString,
            ),
            'LookUpModel': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.SerializeToString,
            ),
            'ListUserModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.SerializeToString,
            ),
            'CreateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.SerializeToString,
            ),
            'CreateUserModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.CreateUserModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.SerializeToString,
            ),
            'UpdateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.SerializeToString,
            ),
            'DeleteUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.SerializeToString,
            ),
            'RenameUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.SerializeToString,
            ),
            'PublishUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelResponse.SerializeToString,
            ),
            'UnpublishUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UnpublishUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelResponse.SerializeToString,
            ),
            'DeployUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelResponse.SerializeToString,
            ),
            'UndeployUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelResponse.SerializeToString,
            ),
            'GetUserModelCard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserModelCard,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardResponse.SerializeToString,
            ),
            'WatchUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.SerializeToString,
            ),
            'TriggerUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.SerializeToString,
            ),
            'TriggerUserModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerUserModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.SerializeToString,
            ),
            'ListOrganizationModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.SerializeToString,
            ),
            'CreateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.SerializeToString,
            ),
            'CreateOrganizationModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.CreateOrganizationModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.SerializeToString,
            ),
            'UpdateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.SerializeToString,
            ),
            'DeleteOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.SerializeToString,
            ),
            'RenameOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.SerializeToString,
            ),
            'PublishOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelResponse.SerializeToString,
            ),
            'UnpublishOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UnpublishOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelResponse.SerializeToString,
            ),
            'DeployOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelResponse.SerializeToString,
            ),
            'UndeployOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelResponse.SerializeToString,
            ),
            'GetOrganizationModelCard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationModelCard,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardResponse.SerializeToString,
            ),
            'WatchOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.SerializeToString,
            ),
            'TriggerOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.SerializeToString,
            ),
            'TriggerOrganizationModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'model.model.v1alpha.ModelPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPublicService(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Liveness',
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Readiness',
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModelDefinitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/LookUpModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListUserModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/CreateUserModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/PublishUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnpublishUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UnpublishUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeployUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UndeployUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserModelCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserModelCard',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/CreateOrganizationModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/PublishOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnpublishOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UnpublishOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeployOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UndeployOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationModelCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationModelCard',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# generated by datamodel-codegen:
#   filename:  huggingface_task_audio_classification_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Input:
    audio: str
    model: Optional[str] = None



# generated by datamodel-codegen:
#   filename:  instill_task_image_to_image_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Output:
    images: List[str]



# generated by datamodel-codegen:
#   filename:  openai_task_speech_recognition_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    text: str



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2
from vdp.pipeline.v1beta import connector_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__pb2
from vdp.pipeline.v1beta import connector_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__definition__pb2
from vdp.pipeline.v1beta import operator_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_operator__definition__pb2
from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1vdp/pipeline/v1beta/pipeline_public_service.proto\x12\x13vdp.pipeline.v1beta\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a vdp/pipeline/v1beta/common.proto\x1a#vdp/pipeline/v1beta/connector.proto\x1a.vdp/pipeline/v1beta/connector_definition.proto\x1a-vdp/pipeline/v1beta/operator_definition.proto\x1a\"vdp/pipeline/v1beta/pipeline.proto2\xe2v\n\x15PipelinePublicService\x12\x9e\x01\n\x08Liveness\x12$.vdp.pipeline.v1beta.LivenessRequest\x1a%.vdp.pipeline.v1beta.LivenessResponse\"E\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\x12\x12/v1beta/__livenessZ\x19\x12\x17/v1beta/health/pipeline\x12\x87\x01\n\tReadiness\x12%.vdp.pipeline.v1beta.ReadinessRequest\x1a&.vdp.pipeline.v1beta.ReadinessResponse\"+\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x15\x12\x13/v1beta/__readiness\x12\x81\x01\n\rListPipelines\x12).vdp.pipeline.v1beta.ListPipelinesRequest\x1a*.vdp.pipeline.v1beta.ListPipelinesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1beta/pipelines\x12\xa5\x01\n\x0eLookUpPipeline\x12*.vdp.pipeline.v1beta.LookUpPipelineRequest\x1a+.vdp.pipeline.v1beta.LookUpPipelineResponse\":\xda\x41\tpermalink\x82\xd3\xe4\x93\x02(\x12&/v1beta/{permalink=pipelines/*}/lookUp\x12\xbd\x01\n\x12\x43reateUserPipeline\x12..vdp.pipeline.v1beta.CreateUserPipelineRequest\x1a/.vdp.pipeline.v1beta.CreateUserPipelineResponse\"F\xda\x41\x0fparent,pipeline\x82\xd3\xe4\x93\x02.\"\"/v1beta/{parent=users/*}/pipelines:\x08pipeline\x12\xa7\x01\n\x11ListUserPipelines\x12-.vdp.pipeline.v1beta.ListUserPipelinesRequest\x1a..vdp.pipeline.v1beta.ListUserPipelinesResponse\"3\xda\x41\x06parent\x82\xd3\xe4\x93\x02$\x12\"/v1beta/{parent=users/*}/pipelines\x12\x9f\x01\n\x0fGetUserPipeline\x12+.vdp.pipeline.v1beta.GetUserPipelineRequest\x1a,.vdp.pipeline.v1beta.GetUserPipelineResponse\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1beta/{name=users/*/pipelines/*}\x12\xcb\x01\n\x12UpdateUserPipeline\x12..vdp.pipeline.v1beta.UpdateUserPipelineRequest\x1a/.vdp.pipeline.v1beta.UpdateUserPipelineResponse\"T\xda\x41\x14pipeline,update_mask\x82\xd3\xe4\x93\x02\x37\x32+/v1beta/{pipeline.name=users/*/pipelines/*}:\x08pipeline\x12\xa8\x01\n\x12\x44\x65leteUserPipeline\x12..vdp.pipeline.v1beta.DeleteUserPipelineRequest\x1a/.vdp.pipeline.v1beta.DeleteUserPipelineResponse\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$*\"/v1beta/{name=users/*/pipelines/*}\x12\xba\x01\n\x14ValidateUserPipeline\x12\x30.vdp.pipeline.v1beta.ValidateUserPipelineRequest\x1a\x31.vdp.pipeline.v1beta.ValidateUserPipelineResponse\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\"+/v1beta/{name=users/*/pipelines/*}/validate:\x01*\x12\xc2\x01\n\x12RenameUserPipeline\x12..vdp.pipeline.v1beta.RenameUserPipelineRequest\x1a/.vdp.pipeline.v1beta.RenameUserPipelineResponse\"K\xda\x41\x14name,new_pipeline_id\x82\xd3\xe4\x93\x02.\")/v1beta/{name=users/*/pipelines/*}/rename:\x01*\x12\xb5\x01\n\x11\x43loneUserPipeline\x12-.vdp.pipeline.v1beta.CloneUserPipelineRequest\x1a..vdp.pipeline.v1beta.CloneUserPipelineResponse\"A\xda\x41\x0bname,target\x82\xd3\xe4\x93\x02-\"(/v1beta/{name=users/*/pipelines/*}/clone:\x01*\x12\xbd\x01\n\x13TriggerUserPipeline\x12/.vdp.pipeline.v1beta.TriggerUserPipelineRequest\x1a\x30.vdp.pipeline.v1beta.TriggerUserPipelineResponse\"C\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02/\"*/v1beta/{name=users/*/pipelines/*}/trigger:\x01*\x12\xd1\x01\n\x18TriggerAsyncUserPipeline\x12\x34.vdp.pipeline.v1beta.TriggerAsyncUserPipelineRequest\x1a\x35.vdp.pipeline.v1beta.TriggerAsyncUserPipelineResponse\"H\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02\x34\"//v1beta/{name=users/*/pipelines/*}/triggerAsync:\x01*\x12\xdb\x01\n\x19\x43reateUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.CreateUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.CreateUserPipelineReleaseResponse\"O\xda\x41\x0eparent,release\x82\xd3\xe4\x93\x02\x38\"-/v1beta/{parent=users/*/pipelines/*}/releases:\x07release\x12\xca\x01\n\x18ListUserPipelineReleases\x12\x34.vdp.pipeline.v1beta.ListUserPipelineReleasesRequest\x1a\x35.vdp.pipeline.v1beta.ListUserPipelineReleasesResponse\"A\xda\x41\tpipelines\x82\xd3\xe4\x93\x02/\x12-/v1beta/{parent=users/*/pipelines/*}/releases\x12\xbf\x01\n\x16GetUserPipelineRelease\x12\x32.vdp.pipeline.v1beta.GetUserPipelineReleaseRequest\x1a\x33.vdp.pipeline.v1beta.GetUserPipelineReleaseResponse\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/\x12-/v1beta/{name=users/*/pipelines/*/releases/*}\x12\xe8\x01\n\x19UpdateUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.UpdateUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.UpdateUserPipelineReleaseResponse\"\\\xda\x41\x13release,update_mask\x82\xd3\xe4\x93\x02@25/v1beta/{release.name=users/*/pipelines/*/releases/*}:\x07release\x12\xc8\x01\n\x19\x44\x65leteUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.DeleteUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.DeleteUserPipelineReleaseResponse\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/*-/v1beta/{name=users/*/pipelines/*/releases/*}\x12\xd3\x01\n\x1aRestoreUserPipelineRelease\x12\x36.vdp.pipeline.v1beta.RestoreUserPipelineReleaseRequest\x1a\x37.vdp.pipeline.v1beta.RestoreUserPipelineReleaseResponse\"D\xda\x41\x04name\x82\xd3\xe4\x93\x02\x37\"5/v1beta/{name=users/*/pipelines/*/releases/*}/restore\x12\xcb\x01\n\x18WatchUserPipelineRelease\x12\x34.vdp.pipeline.v1beta.WatchUserPipelineReleaseRequest\x1a\x35.vdp.pipeline.v1beta.WatchUserPipelineReleaseResponse\"B\xda\x41\x04name\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta/{name=users/*/pipelines/*/releases/*}/watch\x12\xea\x01\n\x19RenameUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.RenameUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.RenameUserPipelineReleaseResponse\"^\xda\x41\x1cname,new_pipeline_release_id\x82\xd3\xe4\x93\x02\x39\"4/v1beta/{name=users/*/pipelines/*/releases/*}/rename:\x01*\x12\xdd\x01\n\x1aTriggerUserPipelineRelease\x12\x36.vdp.pipeline.v1beta.TriggerUserPipelineReleaseRequest\x1a\x37.vdp.pipeline.v1beta.TriggerUserPipelineReleaseResponse\"N\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02:\"5/v1beta/{name=users/*/pipelines/*/releases/*}/trigger:\x01*\x12\xf1\x01\n\x1fTriggerAsyncUserPipelineRelease\x12;.vdp.pipeline.v1beta.TriggerAsyncUserPipelineReleaseRequest\x1a<.vdp.pipeline.v1beta.TriggerAsyncUserPipelineReleaseResponse\"S\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02?\":/v1beta/{name=users/*/pipelines/*/releases/*}/triggerAsync:\x01*\x12\xdd\x01\n\x1a\x43reateOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.CreateOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.CreateOrganizationPipelineResponse\"N\xda\x41\x0fparent,pipeline\x82\xd3\xe4\x93\x02\x36\"*/v1beta/{parent=organizations/*}/pipelines:\x08pipeline\x12\xc7\x01\n\x19ListOrganizationPipelines\x12\x35.vdp.pipeline.v1beta.ListOrganizationPipelinesRequest\x1a\x36.vdp.pipeline.v1beta.ListOrganizationPipelinesResponse\";\xda\x41\x06parent\x82\xd3\xe4\x93\x02,\x12*/v1beta/{parent=organizations/*}/pipelines\x12\xbf\x01\n\x17GetOrganizationPipeline\x12\x33.vdp.pipeline.v1beta.GetOrganizationPipelineRequest\x1a\x34.vdp.pipeline.v1beta.GetOrganizationPipelineResponse\"9\xda\x41\x04name\x82\xd3\xe4\x93\x02,\x12*/v1beta/{name=organizations/*/pipelines/*}\x12\xeb\x01\n\x1aUpdateOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.UpdateOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.UpdateOrganizationPipelineResponse\"\\\xda\x41\x14pipeline,update_mask\x82\xd3\xe4\x93\x02?23/v1beta/{pipeline.name=organizations/*/pipelines/*}:\x08pipeline\x12\xc8\x01\n\x1a\x44\x65leteOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.DeleteOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.DeleteOrganizationPipelineResponse\"9\xda\x41\x04name\x82\xd3\xe4\x93\x02,**/v1beta/{name=organizations/*/pipelines/*}\x12\xda\x01\n\x1cValidateOrganizationPipeline\x12\x38.vdp.pipeline.v1beta.ValidateOrganizationPipelineRequest\x1a\x39.vdp.pipeline.v1beta.ValidateOrganizationPipelineResponse\"E\xda\x41\x04name\x82\xd3\xe4\x93\x02\x38\"3/v1beta/{name=organizations/*/pipelines/*}/validate:\x01*\x12\xe2\x01\n\x1aRenameOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.RenameOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.RenameOrganizationPipelineResponse\"S\xda\x41\x14name,new_pipeline_id\x82\xd3\xe4\x93\x02\x36\"1/v1beta/{name=organizations/*/pipelines/*}/rename:\x01*\x12\xd5\x01\n\x19\x43loneOrganizationPipeline\x12\x35.vdp.pipeline.v1beta.CloneOrganizationPipelineRequest\x1a\x36.vdp.pipeline.v1beta.CloneOrganizationPipelineResponse\"I\xda\x41\x0bname,target\x82\xd3\xe4\x93\x02\x35\"0/v1beta/{name=organizations/*/pipelines/*}/clone:\x01*\x12\xdd\x01\n\x1bTriggerOrganizationPipeline\x12\x37.vdp.pipeline.v1beta.TriggerOrganizationPipelineRequest\x1a\x38.vdp.pipeline.v1beta.TriggerOrganizationPipelineResponse\"K\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02\x37\"2/v1beta/{name=organizations/*/pipelines/*}/trigger:\x01*\x12\xf1\x01\n TriggerAsyncOrganizationPipeline\x12<.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineRequest\x1a=.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineResponse\"P\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02<\"7/v1beta/{name=organizations/*/pipelines/*}/triggerAsync:\x01*\x12\xfb\x01\n!CreateOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.CreateOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.CreateOrganizationPipelineReleaseResponse\"W\xda\x41\x0eparent,release\x82\xd3\xe4\x93\x02@\"5/v1beta/{parent=organizations/*/pipelines/*}/releases:\x07release\x12\xea\x01\n ListOrganizationPipelineReleases\x12<.vdp.pipeline.v1beta.ListOrganizationPipelineReleasesRequest\x1a=.vdp.pipeline.v1beta.ListOrganizationPipelineReleasesResponse\"I\xda\x41\tpipelines\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/{parent=organizations/*/pipelines/*}/releases\x12\xdf\x01\n\x1eGetOrganizationPipelineRelease\x12:.vdp.pipeline.v1beta.GetOrganizationPipelineReleaseRequest\x1a;.vdp.pipeline.v1beta.GetOrganizationPipelineReleaseResponse\"D\xda\x41\x04name\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/{name=organizations/*/pipelines/*/releases/*}\x12\x88\x02\n!UpdateOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.UpdateOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.UpdateOrganizationPipelineReleaseResponse\"d\xda\x41\x13release,update_mask\x82\xd3\xe4\x93\x02H2=/v1beta/{release.name=organizations/*/pipelines/*/releases/*}:\x07release\x12\xe8\x01\n!DeleteOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.DeleteOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.DeleteOrganizationPipelineReleaseResponse\"D\xda\x41\x04name\x82\xd3\xe4\x93\x02\x37*5/v1beta/{name=organizations/*/pipelines/*/releases/*}\x12\xf3\x01\n\"RestoreOrganizationPipelineRelease\x12>.vdp.pipeline.v1beta.RestoreOrganizationPipelineReleaseRequest\x1a?.vdp.pipeline.v1beta.RestoreOrganizationPipelineReleaseResponse\"L\xda\x41\x04name\x82\xd3\xe4\x93\x02?\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/restore\x12\xeb\x01\n WatchOrganizationPipelineRelease\x12<.vdp.pipeline.v1beta.WatchOrganizationPipelineReleaseRequest\x1a=.vdp.pipeline.v1beta.WatchOrganizationPipelineReleaseResponse\"J\xda\x41\x04name\x82\xd3\xe4\x93\x02=\x12;/v1beta/{name=organizations/*/pipelines/*/releases/*}/watch\x12\x8a\x02\n!RenameOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.RenameOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.RenameOrganizationPipelineReleaseResponse\"f\xda\x41\x1cname,new_pipeline_release_id\x82\xd3\xe4\x93\x02\x41\"</v1beta/{name=organizations/*/pipelines/*/releases/*}/rename:\x01*\x12\xfd\x01\n\"TriggerOrganizationPipelineRelease\x12>.vdp.pipeline.v1beta.TriggerOrganizationPipelineReleaseRequest\x1a?.vdp.pipeline.v1beta.TriggerOrganizationPipelineReleaseResponse\"V\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02\x42\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/trigger:\x01*\x12\x91\x02\n\'TriggerAsyncOrganizationPipelineRelease\x12\x43.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineReleaseRequest\x1a\x44.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineReleaseResponse\"[\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02G\"B/v1beta/{name=organizations/*/pipelines/*/releases/*}/triggerAsync:\x01*\x12\x8f\x01\n\x0cGetOperation\x12(.vdp.pipeline.v1beta.GetOperationRequest\x1a).vdp.pipeline.v1beta.GetOperationResponse\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1beta/{name=operations/*}\x12\xae\x01\n\x18ListConnectorDefinitions\x12\x34.vdp.pipeline.v1beta.ListConnectorDefinitionsRequest\x1a\x35.vdp.pipeline.v1beta.ListConnectorDefinitionsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1beta/connector-definitions\x12\xb8\x01\n\x16GetConnectorDefinition\x12\x32.vdp.pipeline.v1beta.GetConnectorDefinitionRequest\x1a\x33.vdp.pipeline.v1beta.GetConnectorDefinitionResponse\"5\xda\x41\x04name\x82\xd3\xe4\x93\x02(\x12&/v1beta/{name=connector-definitions/*}\x12\xaa\x01\n\x17ListOperatorDefinitions\x12\x33.vdp.pipeline.v1beta.ListOperatorDefinitionsRequest\x1a\x34.vdp.pipeline.v1beta.ListOperatorDefinitionsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1beta/operator-definitions\x12\xb4\x01\n\x15GetOperatorDefinition\x12\x31.vdp.pipeline.v1beta.GetOperatorDefinitionRequest\x1a\x32.vdp.pipeline.v1beta.GetOperatorDefinitionResponse\"4\xda\x41\x04name\x82\xd3\xe4\x93\x02\'\x12%/v1beta/{name=operator-definitions/*}\x12\x85\x01\n\x0eListConnectors\x12*.vdp.pipeline.v1beta.ListConnectorsRequest\x1a+.vdp.pipeline.v1beta.ListConnectorsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1beta/connectors\x12\xa9\x01\n\x0fLookUpConnector\x12+.vdp.pipeline.v1beta.LookUpConnectorRequest\x1a,.vdp.pipeline.v1beta.LookUpConnectorResponse\";\xda\x41\tpermalink\x82\xd3\xe4\x93\x02)\x12\'/v1beta/{permalink=connectors/*}/lookUp\x12\xc3\x01\n\x13\x43reateUserConnector\x12/.vdp.pipeline.v1beta.CreateUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.CreateUserConnectorResponse\"I\xda\x41\x10parent,connector\x82\xd3\xe4\x93\x02\x30\"#/v1beta/{parent=users/*}/connectors:\tconnector\x12\xab\x01\n\x12ListUserConnectors\x12..vdp.pipeline.v1beta.ListUserConnectorsRequest\x1a/.vdp.pipeline.v1beta.ListUserConnectorsResponse\"4\xda\x41\x06parent\x82\xd3\xe4\x93\x02%\x12#/v1beta/{parent=users/*}/connectors\x12\xa3\x01\n\x10GetUserConnector\x12,.vdp.pipeline.v1beta.GetUserConnectorRequest\x1a-.vdp.pipeline.v1beta.GetUserConnectorResponse\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%\x12#/v1beta/{name=users/*/connectors/*}\x12\xd2\x01\n\x13UpdateUserConnector\x12/.vdp.pipeline.v1beta.UpdateUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.UpdateUserConnectorResponse\"X\xda\x41\x15\x63onnector,update_mask\x82\xd3\xe4\x93\x02:2-/v1beta/{connector.name=users/*/connectors/*}:\tconnector\x12\xac\x01\n\x13\x44\x65leteUserConnector\x12/.vdp.pipeline.v1beta.DeleteUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.DeleteUserConnectorResponse\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%*#/v1beta/{name=users/*/connectors/*}\x12\xba\x01\n\x14\x43onnectUserConnector\x12\x30.vdp.pipeline.v1beta.ConnectUserConnectorRequest\x1a\x31.vdp.pipeline.v1beta.ConnectUserConnectorResponse\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\"+/v1beta/{name=users/*/connectors/*}/connect:\x01*\x12\xc6\x01\n\x17\x44isconnectUserConnector\x12\x33.vdp.pipeline.v1beta.DisconnectUserConnectorRequest\x1a\x34.vdp.pipeline.v1beta.DisconnectUserConnectorResponse\"@\xda\x41\x04name\x82\xd3\xe4\x93\x02\x33\"./v1beta/{name=users/*/connectors/*}/disconnect:\x01*\x12\xc7\x01\n\x13RenameUserConnector\x12/.vdp.pipeline.v1beta.RenameUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.RenameUserConnectorResponse\"M\xda\x41\x15name,new_connector_id\x82\xd3\xe4\x93\x02/\"*/v1beta/{name=users/*/connectors/*}/rename:\x01*\x12\xba\x01\n\x14\x45xecuteUserConnector\x12\x30.vdp.pipeline.v1beta.ExecuteUserConnectorRequest\x1a\x31.vdp.pipeline.v1beta.ExecuteUserConnectorResponse\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\"+/v1beta/{name=users/*/connectors/*}/execute:\x01*\x12\xaf\x01\n\x12WatchUserConnector\x12..vdp.pipeline.v1beta.WatchUserConnectorRequest\x1a/.vdp.pipeline.v1beta.WatchUserConnectorResponse\"8\xda\x41\x04name\x82\xd3\xe4\x93\x02+\x12)/v1beta/{name=users/*/connectors/*}/watch\x12\xb5\x01\n\x11TestUserConnector\x12-.vdp.pipeline.v1beta.TestUserConnectorRequest\x1a..vdp.pipeline.v1beta.TestUserConnectorResponse\"A\xda\x41\x04name\x82\xd3\xe4\x93\x02\x34\"2/v1beta/{name=users/*/connectors/*}/testConnection\x12\xe3\x01\n\x1b\x43reateOrganizationConnector\x12\x37.vdp.pipeline.v1beta.CreateOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.CreateOrganizationConnectorResponse\"Q\xda\x41\x10parent,connector\x82\xd3\xe4\x93\x02\x38\"+/v1beta/{parent=organizations/*}/connectors:\tconnector\x12\xcb\x01\n\x1aListOrganizationConnectors\x12\x36.vdp.pipeline.v1beta.ListOrganizationConnectorsRequest\x1a\x37.vdp.pipeline.v1beta.ListOrganizationConnectorsResponse\"<\xda\x41\x06parent\x82\xd3\xe4\x93\x02-\x12+/v1beta/{parent=organizations/*}/connectors\x12\xc3\x01\n\x18GetOrganizationConnector\x12\x34.vdp.pipeline.v1beta.GetOrganizationConnectorRequest\x1a\x35.vdp.pipeline.v1beta.GetOrganizationConnectorResponse\":\xda\x41\x04name\x82\xd3\xe4\x93\x02-\x12+/v1beta/{name=organizations/*/connectors/*}\x12\xf2\x01\n\x1bUpdateOrganizationConnector\x12\x37.vdp.pipeline.v1beta.UpdateOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.UpdateOrganizationConnectorResponse\"`\xda\x41\x15\x63onnector,update_mask\x82\xd3\xe4\x93\x02\x42\x32\x35/v1beta/{connector.name=organizations/*/connectors/*}:\tconnector\x12\xcc\x01\n\x1b\x44\x65leteOrganizationConnector\x12\x37.vdp.pipeline.v1beta.DeleteOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.DeleteOrganizationConnectorResponse\":\xda\x41\x04name\x82\xd3\xe4\x93\x02-*+/v1beta/{name=organizations/*/connectors/*}\x12\xda\x01\n\x1c\x43onnectOrganizationConnector\x12\x38.vdp.pipeline.v1beta.ConnectOrganizationConnectorRequest\x1a\x39.vdp.pipeline.v1beta.ConnectOrganizationConnectorResponse\"E\xda\x41\x04name\x82\xd3\xe4\x93\x02\x38\"3/v1beta/{name=organizations/*/connectors/*}/connect:\x01*\x12\xe6\x01\n\x1f\x44isconnectOrganizationConnector\x12;.vdp.pipeline.v1beta.DisconnectOrganizationConnectorRequest\x1a<.vdp.pipeline.v1beta.DisconnectOrganizationConnectorResponse\"H\xda\x41\x04name\x82\xd3\xe4\x93\x02;\"6/v1beta/{name=organizations/*/connectors/*}/disconnect:\x01*\x12\xe7\x01\n\x1bRenameOrganizationConnector\x12\x37.vdp.pipeline.v1beta.RenameOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.RenameOrganizationConnectorResponse\"U\xda\x41\x15name,new_connector_id\x82\xd3\xe4\x93\x02\x37\"2/v1beta/{name=organizations/*/connectors/*}/rename:\x01*\x12\xda\x01\n\x1c\x45xecuteOrganizationConnector\x12\x38.vdp.pipeline.v1beta.ExecuteOrganizationConnectorRequest\x1a\x39.vdp.pipeline.v1beta.ExecuteOrganizationConnectorResponse\"E\xda\x41\x04name\x82\xd3\xe4\x93\x02\x38\"3/v1beta/{name=organizations/*/connectors/*}/execute:\x01*\x12\xcf\x01\n\x1aWatchOrganizationConnector\x12\x36.vdp.pipeline.v1beta.WatchOrganizationConnectorRequest\x1a\x37.vdp.pipeline.v1beta.WatchOrganizationConnectorResponse\"@\xda\x41\x04name\x82\xd3\xe4\x93\x02\x33\x12\x31/v1beta/{name=organizations/*/connectors/*}/watch\x12\xd5\x01\n\x19TestOrganizationConnector\x12\x35.vdp.pipeline.v1beta.TestOrganizationConnectorRequest\x1a\x36.vdp.pipeline.v1beta.TestOrganizationConnectorResponse\"I\xda\x41\x04name\x82\xd3\xe4\x93\x02<\":/v1beta/{name=organizations/*/connectors/*}/testConnection\x12\x80\x01\n\tCheckName\x12%.vdp.pipeline.v1beta.CheckNameRequest\x1a&.vdp.pipeline.v1beta.CheckNameResponse\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17\"\x12/v1beta/check-name:\x01*\x1a\x19\x92\x41\x16\x12\x14Public VDP endpointsB\xe9\x01\n\x17\x63om.vdp.pipeline.v1betaB\x1aPipelinePublicServiceProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\032PipelinePublicServiceProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _PIPELINEPUBLICSERVICE._options = None
  _PIPELINEPUBLICSERVICE._serialized_options = b'\222A\026\022\024Public VDP endpoints'
  _PIPELINEPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\022\022/v1beta/__livenessZ\031\022\027/v1beta/health/pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\025\022\023/v1beta/__readiness'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelines']._serialized_options = b'\202\323\344\223\002\023\022\021/v1beta/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpPipeline']._serialized_options = b'\332A\tpermalink\202\323\344\223\002(\022&/v1beta/{permalink=pipelines/*}/lookUp'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipeline']._serialized_options = b'\332A\017parent,pipeline\202\323\344\223\002.\"\"/v1beta/{parent=users/*}/pipelines:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelines']._serialized_options = b'\332A\006parent\202\323\344\223\002$\022\"/v1beta/{parent=users/*}/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1beta/{name=users/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipeline']._serialized_options = b'\332A\024pipeline,update_mask\202\323\344\223\00272+/v1beta/{pipeline.name=users/*/pipelines/*}:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002$*\"/v1beta/{name=users/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateUserPipeline']._serialized_options = b'\332A\004name\202\323\344\223\0020\"+/v1beta/{name=users/*/pipelines/*}/validate:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipeline']._serialized_options = b'\332A\024name,new_pipeline_id\202\323\344\223\002.\")/v1beta/{name=users/*/pipelines/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneUserPipeline']._serialized_options = b'\332A\013name,target\202\323\344\223\002-\"(/v1beta/{name=users/*/pipelines/*}/clone:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002/\"*/v1beta/{name=users/*/pipelines/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\0024\"//v1beta/{name=users/*/pipelines/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipelineRelease']._serialized_options = b'\332A\016parent,release\202\323\344\223\0028\"-/v1beta/{parent=users/*/pipelines/*}/releases:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelineReleases']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelineReleases']._serialized_options = b'\332A\tpipelines\202\323\344\223\002/\022-/v1beta/{parent=users/*/pipelines/*}/releases'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002/\022-/v1beta/{name=users/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipelineRelease']._serialized_options = b'\332A\023release,update_mask\202\323\344\223\002@25/v1beta/{release.name=users/*/pipelines/*/releases/*}:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002/*-/v1beta/{name=users/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0027\"5/v1beta/{name=users/*/pipelines/*/releases/*}/restore'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0025\0223/v1beta/{name=users/*/pipelines/*/releases/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipelineRelease']._serialized_options = b'\332A\034name,new_pipeline_release_id\202\323\344\223\0029\"4/v1beta/{name=users/*/pipelines/*/releases/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002:\"5/v1beta/{name=users/*/pipelines/*/releases/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002?\":/v1beta/{name=users/*/pipelines/*/releases/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipeline']._serialized_options = b'\332A\017parent,pipeline\202\323\344\223\0026\"*/v1beta/{parent=organizations/*}/pipelines:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelines']._serialized_options = b'\332A\006parent\202\323\344\223\002,\022*/v1beta/{parent=organizations/*}/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002,\022*/v1beta/{name=organizations/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipeline']._serialized_options = b'\332A\024pipeline,update_mask\202\323\344\223\002?23/v1beta/{pipeline.name=organizations/*/pipelines/*}:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002,**/v1beta/{name=organizations/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateOrganizationPipeline']._serialized_options = b'\332A\004name\202\323\344\223\0028\"3/v1beta/{name=organizations/*/pipelines/*}/validate:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipeline']._serialized_options = b'\332A\024name,new_pipeline_id\202\323\344\223\0026\"1/v1beta/{name=organizations/*/pipelines/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneOrganizationPipeline']._serialized_options = b'\332A\013name,target\202\323\344\223\0025\"0/v1beta/{name=organizations/*/pipelines/*}/clone:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\0027\"2/v1beta/{name=organizations/*/pipelines/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002<\"7/v1beta/{name=organizations/*/pipelines/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipelineRelease']._serialized_options = b'\332A\016parent,release\202\323\344\223\002@\"5/v1beta/{parent=organizations/*/pipelines/*}/releases:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelineReleases']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelineReleases']._serialized_options = b'\332A\tpipelines\202\323\344\223\0027\0225/v1beta/{parent=organizations/*/pipelines/*}/releases'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0027\0225/v1beta/{name=organizations/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipelineRelease']._serialized_options = b'\332A\023release,update_mask\202\323\344\223\002H2=/v1beta/{release.name=organizations/*/pipelines/*/releases/*}:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0027*5/v1beta/{name=organizations/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002?\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/restore'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002=\022;/v1beta/{name=organizations/*/pipelines/*/releases/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipelineRelease']._serialized_options = b'\332A\034name,new_pipeline_release_id\202\323\344\223\002A\"</v1beta/{name=organizations/*/pipelines/*/releases/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002B\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002G\"B/v1beta/{name=organizations/*/pipelines/*/releases/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperation']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperation']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1beta/{name=operations/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectorDefinitions']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectorDefinitions']._serialized_options = b'\202\323\344\223\002\037\022\035/v1beta/connector-definitions'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetConnectorDefinition']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetConnectorDefinition']._serialized_options = b'\332A\004name\202\323\344\223\002(\022&/v1beta/{name=connector-definitions/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOperatorDefinitions']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOperatorDefinitions']._serialized_options = b'\202\323\344\223\002\036\022\034/v1beta/operator-definitions'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperatorDefinition']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperatorDefinition']._serialized_options = b'\332A\004name\202\323\344\223\002\'\022%/v1beta/{name=operator-definitions/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectors']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectors']._serialized_options = b'\202\323\344\223\002\024\022\022/v1beta/connectors'
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpConnector']._serialized_options = b'\332A\tpermalink\202\323\344\223\002)\022\'/v1beta/{permalink=connectors/*}/lookUp'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserConnector']._serialized_options = b'\332A\020parent,connector\202\323\344\223\0020\"#/v1beta/{parent=users/*}/connectors:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserConnectors']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserConnectors']._serialized_options = b'\332A\006parent\202\323\344\223\002%\022#/v1beta/{parent=users/*}/connectors'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\002%\022#/v1beta/{name=users/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserConnector']._serialized_options = b'\332A\025connector,update_mask\202\323\344\223\002:2-/v1beta/{connector.name=users/*/connectors/*}:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\002%*#/v1beta/{name=users/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0020\"+/v1beta/{name=users/*/connectors/*}/connect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0023\"./v1beta/{name=users/*/connectors/*}/disconnect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserConnector']._serialized_options = b'\332A\025name,new_connector_id\202\323\344\223\002/\"*/v1beta/{name=users/*/connectors/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0020\"+/v1beta/{name=users/*/connectors/*}/execute:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\002+\022)/v1beta/{name=users/*/connectors/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['TestUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TestUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0024\"2/v1beta/{name=users/*/connectors/*}/testConnection'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationConnector']._serialized_options = b'\332A\020parent,connector\202\323\344\223\0028\"+/v1beta/{parent=organizations/*}/connectors:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationConnectors']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationConnectors']._serialized_options = b'\332A\006parent\202\323\344\223\002-\022+/v1beta/{parent=organizations/*}/connectors'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002-\022+/v1beta/{name=organizations/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationConnector']._serialized_options = b'\332A\025connector,update_mask\202\323\344\223\002B25/v1beta/{connector.name=organizations/*/connectors/*}:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002-*+/v1beta/{name=organizations/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\0028\"3/v1beta/{name=organizations/*/connectors/*}/connect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002;\"6/v1beta/{name=organizations/*/connectors/*}/disconnect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationConnector']._serialized_options = b'\332A\025name,new_connector_id\202\323\344\223\0027\"2/v1beta/{name=organizations/*/connectors/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\0028\"3/v1beta/{name=organizations/*/connectors/*}/execute:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\0023\0221/v1beta/{name=organizations/*/connectors/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['TestOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TestOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002<\":/v1beta/{name=organizations/*/connectors/*}/testConnection'
  _PIPELINEPUBLICSERVICE.methods_by_name['CheckName']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CheckName']._serialized_options = b'\332A\004name\202\323\344\223\002\027\"\022/v1beta/check-name:\001*'
  _globals['_PIPELINEPUBLICSERVICE']._serialized_start=409
  _globals['_PIPELINEPUBLICSERVICE']._serialized_end=15611
# @@protoc_insertion_point(module_scope)



# generated by datamodel-codegen:
#   filename:  redis_task_chat_message_write_multi_modal_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Any, Dict, List, Optional


@dataclass
class ImageUrl:
    url: str


class Type(Enum):
    text = 'text'
    image_url = 'image_url'


@dataclass
class ContentItem:
    type: Type
    image_url: Optional[ImageUrl] = None
    text: Optional[str] = None


@dataclass
class Input:
    content: List[ContentItem]
    role: str
    session_id: str
    metadata: Optional[Dict[str, Any]] = None



# generated by datamodel-codegen:
#   filename:  openai_task_text_to_speech_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Optional, Union


class Model(Enum):
    tts_1 = 'tts-1'
    tts_1_hd = 'tts-1-hd'


class ResponseFormat(Enum):
    mp3 = 'mp3'
    opus = 'opus'
    aac = 'aac'
    flac = 'flac'


class Voice(Enum):
    alloy = 'alloy'
    echo = 'echo'
    fable = 'fable'
    onyx = 'onyx'
    nova = 'nova'
    shimmer = 'shimmer'


@dataclass
class Input:
    model: Union[str, Model]
    text: str
    voice: Voice
    response_format: Optional[ResponseFormat] = ResponseFormat.mp3
    speed: Optional[float] = 1



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2


class ArtifactPublicServiceStub(object):
    """Artifact

    ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
                )


class ArtifactPublicServiceServicer(object):
    """Artifact

    ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def Liveness(self, request, context):
        """Check if the artifact server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the artifact server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ArtifactPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'artifact.artifact.v1alpha.ArtifactPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ArtifactPublicService(object):
    """Artifact

    ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# generated by datamodel-codegen:
#   filename:  instill_task_semantic_segmentation_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Object:
    category: str
    rle: str


@dataclass
class Model:
    stuffs: List[Object]



# generated by datamodel-codegen:
#   filename:  instill_task_classification_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Model:
    category: str
    score: float



# generated by datamodel-codegen:
#   filename:  openai_task_speech_recognition_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Optional


class Model(Enum):
    whisper_1 = 'whisper-1'


@dataclass
class Input:
    audio: bytes
    model: Model
    language: Optional[str] = None
    prompt: Optional[str] = None
    temperature: Optional[float] = 0



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/model/model/v1alpha/model_private_service.proto\x12\x13model.model.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fmodel/model/v1alpha/model.proto2\xab\x07\n\x13ModelPrivateService\x12\x8b\x01\n\x0fListModelsAdmin\x12+.model.model.v1alpha.ListModelsAdminRequest\x1a,.model.model.v1alpha.ListModelsAdminResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1alpha/admin/models\x12\xaf\x01\n\x10LookUpModelAdmin\x12,.model.model.v1alpha.LookUpModelAdminRequest\x1a-.model.model.v1alpha.LookUpModelAdminResponse\">\xda\x41\tpermalink\x82\xd3\xe4\x93\x02,\x12*/v1alpha/admin/{permalink=models/*}/lookUp\x12\xb7\x01\n\x0f\x43heckModelAdmin\x12+.model.model.v1alpha.CheckModelAdminRequest\x1a,.model.model.v1alpha.CheckModelAdminResponse\"I\xda\x41\x0fmodel_permalink\x82\xd3\xe4\x93\x02\x31\x12//v1alpha/admin/{model_permalink=models/*}/check\x12\xbe\x01\n\x10\x44\x65ployModelAdmin\x12,.model.model.v1alpha.DeployModelAdminRequest\x1a-.model.model.v1alpha.DeployModelAdminResponse\"M\xda\x41\x0fmodel_permalink\x82\xd3\xe4\x93\x02\x35\"0/v1alpha/admin/{model_permalink=models/*}/deploy:\x01*\x12\xc6\x01\n\x12UndeployModelAdmin\x12..model.model.v1alpha.UndeployModelAdminRequest\x1a/.model.model.v1alpha.UndeployModelAdminResponse\"O\xda\x41\x0fmodel_permalink\x82\xd3\xe4\x93\x02\x37\"2/v1alpha/admin/{model_permalink=models/*}/undeploy:\x01*\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xe5\x01\n\x17\x63om.model.model.v1alphaB\x18ModelPrivateServiceProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\030ModelPrivateServiceProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _MODELPRIVATESERVICE._options = None
  _MODELPRIVATESERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _MODELPRIVATESERVICE.methods_by_name['ListModelsAdmin']._options = None
  _MODELPRIVATESERVICE.methods_by_name['ListModelsAdmin']._serialized_options = b'\202\323\344\223\002\027\022\025/v1alpha/admin/models'
  _MODELPRIVATESERVICE.methods_by_name['LookUpModelAdmin']._options = None
  _MODELPRIVATESERVICE.methods_by_name['LookUpModelAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002,\022*/v1alpha/admin/{permalink=models/*}/lookUp'
  _MODELPRIVATESERVICE.methods_by_name['CheckModelAdmin']._options = None
  _MODELPRIVATESERVICE.methods_by_name['CheckModelAdmin']._serialized_options = b'\332A\017model_permalink\202\323\344\223\0021\022//v1alpha/admin/{model_permalink=models/*}/check'
  _MODELPRIVATESERVICE.methods_by_name['DeployModelAdmin']._options = None
  _MODELPRIVATESERVICE.methods_by_name['DeployModelAdmin']._serialized_options = b'\332A\017model_permalink\202\323\344\223\0025\"0/v1alpha/admin/{model_permalink=models/*}/deploy:\001*'
  _MODELPRIVATESERVICE.methods_by_name['UndeployModelAdmin']._options = None
  _MODELPRIVATESERVICE.methods_by_name['UndeployModelAdmin']._serialized_options = b'\332A\017model_permalink\202\323\344\223\0027\"2/v1alpha/admin/{model_permalink=models/*}/undeploy:\001*'
  _globals['_MODELPRIVATESERVICE']._serialized_start=190
  _globals['_MODELPRIVATESERVICE']._serialized_end=1129
# @@protoc_insertion_point(module_scope)



# pylint: disable=no-member,wrong-import-position
import instill.protogen.vdp.pipeline.v1beta.pipeline_pb2 as pipeline_pb
from instill.resources.schema import (
    end_task_end_input,
    end_task_end_metadata,
    helper,
    start_task_start_metadata,
)


def create_start_operator(
    metadata_fields: start_task_start_metadata.Metadata,
) -> pipeline_pb.Component:
    start_operator_component = pipeline_pb.Component()
    start_operator_component.id = "start"
    start_operator_component.resource_name = ""
    start_operator_component.definition_name = "operator-definitions/start"

    for metadata_key, metadata_val in metadata_fields.items():
        metadata_fields[metadata_key] = helper.pop_default_and_to_dict(metadata_val)  # type: ignore
    metadata = {"metadata": metadata_fields}
    start_operator_component.configuration.update(metadata)  # type: ignore

    return start_operator_component


def create_end_operator(
    inp_fields: end_task_end_input.Input,
    metadata_fields: end_task_end_metadata.Metadata,
) -> pipeline_pb.Component:
    end_operator_component = pipeline_pb.Component()
    end_operator_component.id = "end"
    end_operator_component.resource_name = ""
    end_operator_component.definition_name = "operator-definitions/end"

    for metadata_key, metadata_val in metadata_fields.items():
        metadata_fields[metadata_key] = helper.pop_default_and_to_dict(metadata_val)  # type: ignore
    inp = {"input": inp_fields}
    metadata = {"metadata": metadata_fields}
    end_operator_component.configuration.update(inp)
    end_operator_component.configuration.update(metadata)  # type: ignore

    return end_operator_component
